==> openlucius-7.x-1.5.tar.gz: openlucius/themes/openlucius/theme/views/views-view.tpl.php <==
<?php
/**
 * @file
 * Main view template.
 * 
 * Variables available:
 * - $classes_array: An array of classes determined in
 *   template_preprocess_views_view(). Default classes are:
 *     .view
 *     .view-[css_name]
 *     .view-id-[view_name]
 *     .view-display-id-[display_name]
 *     .view-dom-id-[dom_id]
 * - $classes: A string version of $classes_array for use in the class attribute
 * - $css_name: A css-safe version of the view name.
 * - $css_class: The user-specified classes names, if any
 * - $header: The view header
 * - $footer: The view footer
 * - $rows: The results of the view query, if any
 * - $empty: The empty text to display if the view is empty
 * - $pager: The pager next/prev links to display, if any
 * - $exposed: Exposed widget form/info to display
 * - $feed_icon: Feed icon to display, if any
 * - $more: A link to view more, if any
 *
 * @ingroup views_templates
 */
?>
<div class="<?php print $classes; ?>">
  <?php print render($title_prefix); ?>
  <?php print render($title_suffix); ?>

  <?php // TODO we shouldn't have code like this all items are built the same. ?>
  <?php if (!empty($order_todo_lists)): ?>
    <div class="view-actionlink">
      <h4><span class="glyphicon glyphicon-sort"></span>
        <a id="openlucius_order_todolists" href="#"><?php print $order_todo_lists; ?></a>
      </h4>
    </div>
  <?php endif; ?>

  <?php if (!empty($action_link)): ?>
    <div class="view-actionlink">
      <h4>
        <span class="glyphicon glyphicon-<?php print $icon_action_link_1; ?>"></span>
        <?php print $action_link; ?>
      </h4>
    </div>
  <?php endif; ?>

  <?php if (!empty($action_link_2)): ?>
    <div class="view-actionlink">
      <h4><span class="glyphicon glyphicon-plus-sign"></span>
        <?php print $action_link_2; ?>
      </h4>
    </div>
  <?php endif; ?>

  <?php if ($header): ?>
    <div class="view-header">
      <?php if (!empty($username)) :
        print $username;
      endif; ?>
      <?php print $header; ?>
    </div>
  <?php endif; ?>

  <?php if ($exposed): ?>
    <div class="view-filters">
      <?php print $exposed; ?>
    </div>
  <?php endif; ?>

  <?php if ($attachment_before): ?>
    <div class="attachment attachment-before">
      <?php print $attachment_before; ?>
    </div>
  <?php endif; ?>

  <?php if ($rows): ?>
    <div class="view-content">
      <div class="table-responsive">
        <?php print $rows; ?>
      </div>
    </div>
  <?php elseif ($empty): ?>
    <div class="view-empty">
      <?php print $empty; ?>
    </div>
  <?php endif; ?>

  <?php if ($pager): ?>
    <?php print $pager; ?>
  <?php endif; ?>

  <?php if ($attachment_after): ?>
    <div class="attachment attachment-after">
      <?php print $attachment_after; ?>
    </div>
  <?php endif; ?>

  <?php if ($more): ?>
    <?php print $more; ?>
  <?php endif; ?>

  <?php if ($footer): ?>
    <div class="view-footer">
      <?php print $footer; ?>
    </div>
  <?php endif; ?>

  <?php if ($feed_icon): ?>
    <div class="feed-icon">
      <?php print $feed_icon; ?>
    </div>
  <?php endif; ?>
</div><?php /* class view */ ?>

==> openlucius-7.x-1.7.tar.gz: openlucius/themes/openlucius/theme/views/views-view.tpl.php <==
<?php
/**
 * @file
 * Main view template.
 *
 * Variables available:
 * - $classes_array: An array of classes determined in
 *   template_preprocess_views_view(). Default classes are:
 *     .view
 *     .view-[css_name]
 *     .view-id-[view_name]
 *     .view-display-id-[display_name]
 *     .view-dom-id-[dom_id]
 * - $classes: A string version of $classes_array for use in the class attribute
 * - $css_name: A css-safe version of the view name.
 * - $css_class: The user-specified classes names, if any
 * - $header: The view header
 * - $footer: The view footer
 * - $rows: The results of the view query, if any
 * - $empty: The empty text to display if the view is empty
 * - $pager: The pager next/prev links to display, if any
 * - $exposed: Exposed widget form/info to display
 * - $feed_icon: Feed icon to display, if any
 * - $more: A link to view more, if any.
 *
 * @ingroup views_templates
 */
?>
<div class="<?php print $classes; ?>">
  <?php print render($title_prefix); ?>
  <?php print render($title_suffix); ?>

  <?php // TODO we shouldn't have code like this all items are built the same. ?>
  <?php if (!empty($order_todo_lists)): ?>
    <div class="view-actionlink">
      <h4><span class="glyphicon glyphicon-sort"></span>
        <a id="openlucius_order_todolists" href="#"><?php print $order_todo_lists; ?></a>
      </h4>
    </div>
  <?php endif; ?>

  <?php if (!empty($action_link)): ?>
    <div class="view-actionlink">
      <h4>
        <span class="glyphicon glyphicon-<?php print $icon_action_link_1; ?>"></span>
        <?php print $action_link; ?>
      </h4>
    </div>
  <?php endif; ?>

  <?php if (!empty($action_link_2)): ?>
    <div class="view-actionlink">
      <h4><span class="glyphicon glyphicon-plus-sign"></span>
        <?php print $action_link_2; ?>
      </h4>
    </div>
  <?php endif; ?>

  <?php if ($header): ?>
    <div class="view-header">
      <?php if (!empty($username)) :
        print $username;
      endif; ?>
      <?php print $header; ?>
    </div>
  <?php endif; ?>

  <?php if ($exposed): ?>
    <div class="view-filters">
      <?php print $exposed; ?>
    </div>
  <?php endif; ?>

  <?php if ($attachment_before): ?>
    <div class="attachment attachment-before">
      <?php print $attachment_before; ?>
    </div>
  <?php endif; ?>

  <?php if ($rows): ?>
    <div class="view-content">
      <div class="table-responsive">
        <?php print $rows; ?>
      </div>
    </div>
  <?php elseif ($empty): ?>
    <div class="view-empty">
      <?php print $empty; ?>
    </div>
  <?php endif; ?>

  <?php if ($pager): ?>
    <?php print $pager; ?>
  <?php endif; ?>

  <?php if ($attachment_after): ?>
    <div class="attachment attachment-after">
      <?php print $attachment_after; ?>
    </div>
  <?php endif; ?>

  <?php if ($more): ?>
    <?php print $more; ?>
  <?php endif; ?>

  <?php if ($footer): ?>
    <div class="view-footer">
      <?php print $footer; ?>
    </div>
  <?php endif; ?>

  <?php if ($feed_icon): ?>
    <div class="feed-icon">
      <?php print $feed_icon; ?>
    </div>
  <?php endif; ?>
</div><?php /* class view */ ?>
